==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/SpotInstanceRequestLaunchTemplateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property id ID of the launch template. Conflicts with `name`.
 * @property name Name of the launch template. Conflicts with `id`.
 * @property version Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
 */
public data class SpotInstanceRequestLaunchTemplateArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs =
        com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpotInstanceRequestLaunchTemplateArgs].
 */
@PulumiTagMarker
public class SpotInstanceRequestLaunchTemplateArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value ID of the launch template. Conflicts with `name`.
     */
    @JvmName("tkvdybyrvsoojlwi")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the launch template. Conflicts with `id`.
     */
    @JvmName("rnyseyptxlvwvudu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
     */
    @JvmName("pkmpxoimuevrbpcq")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value ID of the launch template. Conflicts with `name`.
     */
    @JvmName("lgsshimomfaknont")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the launch template. Conflicts with `id`.
     */
    @JvmName("rpscqxfshbdbnhmr")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
     */
    @JvmName("ygfotajvbtvodeow")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): SpotInstanceRequestLaunchTemplateArgs =
        SpotInstanceRequestLaunchTemplateArgs(
            id = id,
            name = name,
            version = version,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/SpotInstanceRequestLaunchTemplateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property id ID of the launch template. Conflicts with `name`.
 * @property name Name of the launch template. Conflicts with `id`.
 * @property version Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
 */
public data class SpotInstanceRequestLaunchTemplateArgs(
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs =
        com.pulumi.aws.ec2.inputs.SpotInstanceRequestLaunchTemplateArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpotInstanceRequestLaunchTemplateArgs].
 */
@PulumiTagMarker
public class SpotInstanceRequestLaunchTemplateArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value ID of the launch template. Conflicts with `name`.
     */
    @JvmName("krqojkryydqdfuop")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the launch template. Conflicts with `id`.
     */
    @JvmName("svsielvexmxiskuq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
     */
    @JvmName("pmmwvpaefaohvttu")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value ID of the launch template. Conflicts with `name`.
     */
    @JvmName("xxdxbnewdgjyiahn")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Name of the launch template. Conflicts with `id`.
     */
    @JvmName("jhxeltvibtdbpvhw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Template version. Can be a specific version number, `$Latest` or `$Default`. The default value is `$Default`.
     */
    @JvmName("rrbhpbyfxavfubxc")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): SpotInstanceRequestLaunchTemplateArgs =
        SpotInstanceRequestLaunchTemplateArgs(
            id = id,
            name = name,
            version = version,
        )
}
